//
//  BLETestViewController.m
//  SDKForTest
//
//  Created by Michael on 17/5/23.
//  Copyright © 2017年 Michael. All rights reserved.
//

#import "BLETestViewController.h"
#import "ASHeartRecordSearchBlueTableViewCell.h"
#import <AngelDoctorFrame/AngelDoctorBluetooth.h>
#import <AngelDoctorFrame/AngelDoctorDevice.h>
#import <AngelDoctorFrame/AngelDoctorBluetoothModel.h>

@interface BLETestViewController ()<AngelDoctorDelegate,UITableViewDelegate,UITableViewDataSource,UIActionSheetDelegate>
@property (nonatomic, strong) AngelDoctorBluetooth *bluetooth;

@property (nonatomic, strong) UITableView *deviceTableView;

@property (nonatomic, strong) NSMutableArray *deviceArr;

@property (nonatomic, strong) AngelDoctorBluetoothModel *myModel;

@property (nonatomic, assign) AngelDoctorDeviceType selectType;

@property (strong, nonatomic) IBOutlet UILabel *SpoValue;
@property (strong, nonatomic) IBOutlet UILabel *PlusValue;

@property (strong, nonatomic) IBOutlet UILabel *PIValue;
@property (strong, nonatomic) IBOutlet UILabel *tempValue;
@property (strong, nonatomic) IBOutlet UILabel *weightValue;
@property (strong, nonatomic) IBOutlet UILabel *weightStateValue;
@property (strong, nonatomic) IBOutlet UILabel *macAddress;

@end

@implementation BLETestViewController



- (void)viewDidLoad{
    [super viewDidLoad];
    
    self.view.backgroundColor = [UIColor whiteColor];
    self.deviceArr = [NSMutableArray new];
    
    self.deviceTableView = [[UITableView alloc] initWithFrame:CGRectMake(0, 64, self.view.bounds.size.width, 180) style:UITableViewStylePlain];
    self.deviceTableView.backgroundColor = [UIColor colorWithRed:250.0/255.f green:250.0/255.f blue:250.0/255.f alpha:1.0];
    self.deviceTableView.dataSource = self;
    self.deviceTableView.delegate = self;
    self.deviceTableView.separatorStyle = UITableViewCellSeparatorStyleNone;
    [self.view addSubview:self.deviceTableView];

    
}

- (IBAction)SelectTypeAction:(UIButton *)sender {
    
   
    
    UIActionSheet *actionSheet = [[UIActionSheet alloc] initWithTitle:@"选择设备类型" delegate:self cancelButtonTitle:@"取消" destructiveButtonTitle:nil otherButtonTitles:@"体温计",@"血氧仪",@"体重秤", nil];
    [actionSheet showInView:self.view];

}
- (void)actionSheet:(UIActionSheet *)actionSheet clickedButtonAtIndex:(NSInteger)buttonIndex{
    // 断开蓝牙连接
    [self.bluetooth clearUpBluetooth];
    
    switch (buttonIndex) {
        case 0:
            self.selectType = AngelDoctorTempreatrueType;
            break;
        case 1:
            self.selectType = AngelDoctorSpo2Type;
            break;
        case 2:
            self.selectType = AngelDoctorWeightType;
            break;
        default:
            break;
    }
    self.SpoValue.text = nil;
    self.PlusValue.text =nil;
    self.PIValue.text = nil;
    self.macAddress.text = nil;
    self.weightValue.text = nil;
    self.weightStateValue.text = nil;
    // 初始化天使医生SDK蓝牙类
    self.bluetooth = [[AngelDoctorBluetooth alloc] init];
    self.bluetooth.delegate = self;
    [self.bluetooth scanPeripheral];
}

- (void)findNewDevice:(NSMutableArray *)deviceArray{
    
    self.deviceArr =deviceArray;
    [self.deviceTableView reloadData];
}
- (void)showMessageError:(NSString *)msg{
    dispatch_async(dispatch_get_main_queue(), ^{
        UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:msg message:nil delegate:nil cancelButtonTitle:@"取消" otherButtonTitles:@"确定", nil];
        [alertView show];
    });
}
- (void)getData:(id)model withDeviceType:(NSInteger)type withConnectType:(NSInteger)connectType withWeightProtocol:(NSInteger)protocol{
    
    AngelDoctorBluetoothModel * bluetoothModel = [[AngelDoctorBluetoothModel alloc] init];
    [bluetoothModel analysisData:model withDeviceType:type withConnectType:connectType withWeightProtocol:protocol];
    if (bluetoothModel.SPO != NULL) {
        self.SpoValue.text = bluetoothModel.SPO;
        self.PlusValue.text = bluetoothModel.Plus;
        self.PIValue.text = bluetoothModel.PI;
    }

    self.tempValue.text = bluetoothModel.temperatureValue;
    if (bluetoothModel.weightValue != NULL) {
        self.weightValue.text = bluetoothModel.weightValue;
    }
    if ([bluetoothModel.weightState isEqualToString:@"measureResult"]) {
        self.weightStateValue.text =@"测量出结果";
    }else if([bluetoothModel.weightState isEqualToString:@"measuring"]){
        self.weightStateValue.text =@"测量中...";
    }
    
}

- (void)connectPeripheralState:(CBPeripheralState)peripheralState{
    
    if (peripheralState == CBPeripheralStateConnected) {
        NSLog(@"连接成功");
    }else if (peripheralState == CBPeripheralStateConnecting){
        NSLog(@"连接中...");
    }else if (peripheralState == CBPeripheralStateDisconnected){
        NSLog(@"断开连接");
    }
}

#pragma mark - tableViewDelegate -
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return self.deviceArr.count;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath{
    return 44;
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    ASHeartRecordSearchBlueTableViewCell *cell = [ASHeartRecordSearchBlueTableViewCell cellWithTableView:tableView];
    AngelDoctorDevice *device = self.deviceArr[indexPath.row];
    cell.blueToothNameLable.text = device.name;
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{
    AngelDoctorDevice *device = self.deviceArr[indexPath.row];
    self.macAddress.text = device.macAddress;
    [self.bluetooth connectDevice:device withDeviceType:self.selectType];
}

@end
